/**
 * Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 * THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 * AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 * UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 * This notice may not be removed from this file.
 */

package com.compdfkit.tools.common.contextmenu.impl;


import android.graphics.Bitmap;
import android.graphics.RectF;
import android.view.LayoutInflater;
import android.view.View;

import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;

import com.compdfkit.tools.R;
import com.compdfkit.tools.common.contextmenu.CPDFContextMenuHelper;
import com.compdfkit.tools.common.contextmenu.interfaces.ContextMenuScreenShotProvider;
import com.compdfkit.tools.common.contextmenu.provider.ContextMenuView;
import com.compdfkit.tools.common.pdf.CPDFDocumentFragment;
import com.compdfkit.tools.common.utils.CFileUtils;
import com.compdfkit.tools.common.utils.date.CDateUtil;
import com.compdfkit.tools.common.utils.image.CImageUtil;
import com.compdfkit.tools.common.utils.viewutils.CViewUtils;
import com.compdfkit.ui.reader.CPDFPageView;
import com.compdfkit.ui.reader.CPDFReaderView;

import java.io.File;

public class CScreenShotContextMenuView implements ContextMenuScreenShotProvider {


    @Override
    public View getScreenShotContentView(CPDFContextMenuHelper helper, CPDFPageView pageView, LayoutInflater inflater, RectF rectF) {
        ContextMenuView menuView = new ContextMenuView(pageView.getContext());
        menuView.addItem(R.string.tools_exit, v -> {
            exitScreenShot(helper, pageView);
        });
        menuView.addItem(R.string.tools_share, v -> {
            try{
                Bitmap bitmap = pageView.getScreenshotBitmap();
                if (bitmap == null){
                    exitScreenShot(helper, pageView);
                    return;
                }
                String fileName = "screenshot_"+ CDateUtil.getDataTime(CDateUtil.NORMAL_DATE_FORMAT)+".png";
                String screenShotFilePath = CImageUtil.saveBitmap(pageView.getContext(), fileName, bitmap);
                CFileUtils.shareFile(menuView.getContext(), pageView.getContext().getString(R.string.tools_share), "image/*", new File(screenShotFilePath));
                exitScreenShot(helper, pageView);
            }catch (Exception e){
                e.printStackTrace();
                exitScreenShot(helper, pageView);
            }
        });
        return menuView;
    }

    private void exitScreenShot(CPDFContextMenuHelper helper, CPDFPageView pageView){
        CPDFReaderView readerView = helper.getReaderView();
        FragmentActivity fragmentActivity = CViewUtils.getFragmentActivity(readerView.getContext());
        if (fragmentActivity != null){
            Fragment fragment = fragmentActivity.getSupportFragmentManager()
                    .findFragmentByTag("documentFragment");
            if (fragment != null && fragment instanceof  CPDFDocumentFragment){
                CPDFDocumentFragment documentFragment = (CPDFDocumentFragment) fragment;
                documentFragment.exitScreenShot();
            }
        }
    }

}
